@@ -1,23 +1,26 @@
 package POEx::ZMQ3::Subscriber;
-{
-  $POEx::ZMQ3::Subscriber::VERSION = '0.060003';
-}
-
+$POEx::ZMQ3::Subscriber::VERSION = '0.060004';
 use Carp;
-use Moo;
 use POE;
 
 ## FIXME
 ##  Easier subscription management wrt. multipart_recv
 
-use namespace::clean;
+use Moo;
+with 'POEx::ZMQ3::Role::Emitter';
+
 
 has targets => (
   is => 'rw',
   default => sub { [] },
 );
 
-with 'POEx::ZMQ3::Role::Emitter';
+
+=pod
+
+=for Pod::Coverage build_defined_states emitter_started zmqsock.+
+
+=cut
 
 sub build_defined_states {
   my ($self) = @_;
@@ -104,12 +107,12 @@ POEx::ZMQ3::Subscriber - A SUB-type ZeroMQ socket
         );
       },
 
-      zeromq_subscribed_to => {
+      zeromq_subscribed_to => sub {
         my $target = $_[ARG0];
         print "Subscribed to $target\n";
       },
 
-      zeromq_received => {
+      zeromq_received => sub {
         my $data = $_[ARG0];
         print "Received $data from publisher\n";
 
@@ -168,6 +171,13 @@ parts:
     . . .
   }
 
+=head2 Attributes
+
+=head3 targets
+
+An ARRAY containing the list of publishing endpoints the Subscriber was
+configured for; see L</start>.
+
 =head1 SEE ALSO
 
 L<POEx::ZMQ3>
